use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007002
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Randy
Stauner
rwstauner
David
Steinbrunner
dsteinbrunner
Graham
Knop
haarg
Jeffrey
Ryan
Thalhammer
thaljef
Sawyer
xsawyerx
lib
Dist
Metadata
Archive
Dir
Struct
Tar
Zip
